pub struct RegisteredQuery {
pub id: u64,
pub owner: String,
pub keys: Vec<KVKey>,
pub query_type: QueryType,
pub transactions_filter: String,
pub connection_id: String,
pub update_period: u64,
pub last_submitted_result_local_height: u64,
pub last_submitted_result_remote_height: Height,
pub deposit: Vec<Coin>,
pub submit_timeout: u64,
pub registered_at_height: u64,
}Fields
id: u64The unique id of the registered query.
owner: StringThe address that registered the query.
keys: Vec<KVKey>The KV-storage keys for which we want to get values from remote chain
query_type: QueryTypeThe query type identifier (i.e. ‘kv’ or ‘tx’ for now)
transactions_filter: StringThe filter for transaction search ICQ
connection_id: StringThe IBC connection ID for getting ConsensusState to verify proofs.
update_period: u64Parameter that defines how often the query must be updated.
last_submitted_result_local_height: u64The local chain last block height when the query result was updated.
last_submitted_result_remote_height: HeightThe remote chain last block height when the query result was updated.
deposit: Vec<Coin>Amount of coins deposited for the query.
submit_timeout: u64Timeout before query becomes available for everybody to remove.
registered_at_height: u64The local chain height when the query was registered.